@@ -1,18 +1,31 @@
+/* This file is part of the GNU plotutils package.  Copyright (C) 1995,
+   1996, 1997, 1998, 1999, 2000, 2005, Free Software Foundation, Inc.
+
+   The GNU plotutils package is free software.  You may redistribute it
+   and/or modify it under the terms of the GNU General Public License as
+   published by the Free Software foundation; either version 2, or (at your
+   option) any later version.
+
+   The GNU plotutils package is distributed in the hope that it will be
+   useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License along
+   with the GNU plotutils package; see the file COPYING.  If not, write to
+   the Free Software Foundation, Inc., 51 Franklin St., Fifth Floor,
+   Boston, MA 02110-1301, USA. */
+
 #include "sys-defines.h"
 #include "extern.h"
 
 bool
-#ifdef _HAVE_PROTOS
-_c_erase_page (S___(Plotter *_plotter))
-#else
-_c_erase_page (S___(_plotter))
-     S___(Plotter *_plotter;)
-#endif
+_pl_c_erase_page (S___(Plotter *_plotter))
 {
   int i;
 
   /* reinitialize `font used' array(s) for this page */
-  for (i = 0; i < NUM_PS_FONTS; i++)
+  for (i = 0; i < PL_NUM_PS_FONTS; i++)
     _plotter->data->page->ps_font_used[i] = false;
 
   /* deallocate table of user-specified line types, if any */
@@ -30,7 +43,7 @@ _c_erase_page (S___(_plotter))
 	  linetype_ptr = linetype_ptr->next;
 	  free (old_linetype_ptr);
 	}
-      _plotter->data->page->extra = (voidptr_t)NULL;
+      _plotter->data->page->extra = (void *)NULL;
     }
 
   /* reset other page-specific, i.e. picture-specific, CGMPlotter
@@ -94,7 +107,7 @@ _c_erase_page (S___(_plotter))
   /* copy the bg color currently in the drawing state to the CGM-specific
      part of the CGMPlotter; it'll be written to the output file at the
      head of the picture */
-  _c_set_bg_color (S___(_plotter));
+  _pl_c_set_bg_color (S___(_plotter));
 
   return true;
 }
