@@ -1,3 +1,21 @@
+/* This file is part of the GNU plotutils package.  Copyright (C) 1995,
+   1996, 1997, 1998, 1999, 2000, 2005, Free Software Foundation, Inc.
+
+   The GNU plotutils package is free software.  You may redistribute it
+   and/or modify it under the terms of the GNU General Public License as
+   published by the Free Software foundation; either version 2, or (at your
+   option) any later version.
+
+   The GNU plotutils package is distributed in the hope that it will be
+   useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License along
+   with the GNU plotutils package; see the file COPYING.  If not, write to
+   the Free Software Foundation, Inc., 51 Franklin St., Fifth Floor,
+   Boston, MA 02110-1301, USA. */
+
 /* For FigPlotter objects, we place all user-defined colors [``color
    pseudo-objects''], which must appear first in the .fig file, in a header
    for the page.
@@ -10,12 +28,7 @@
 #include "extern.h"
 
 bool
-#ifdef _HAVE_PROTOS
-_f_end_page (S___(Plotter *_plotter))
-#else
-_f_end_page (S___(_plotter))
-     S___(Plotter *_plotter;)
-#endif
+_pl_f_end_page (S___(Plotter *_plotter))
 {
   int i;
   const char *units;
