@@ -1,3 +1,21 @@
+/* This file is part of the GNU plotutils package.  Copyright (C) 1995,
+   1996, 1997, 1998, 1999, 2000, 2005, Free Software Foundation, Inc.
+
+   The GNU plotutils package is free software.  You may redistribute it
+   and/or modify it under the terms of the GNU General Public License as
+   published by the Free Software foundation; either version 2, or (at your
+   option) any later version.
+
+   The GNU plotutils package is distributed in the hope that it will be
+   useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License along
+   with the GNU plotutils package; see the file COPYING.  If not, write to
+   the Free Software Foundation, Inc., 51 Franklin St., Fifth Floor,
+   Boston, MA 02110-1301, USA. */
+
 /* The internal point-drawing function, which point() is a wrapper around.
    It draws a point at the current location.  There is no standard
    definition of `point', so any Plotter is free to implement this as it
@@ -15,12 +33,7 @@
 #define P_CLOSED 3
 
 void
-#ifdef _HAVE_PROTOS
-_f_paint_point (S___(Plotter *_plotter))
-#else
-_f_paint_point (S___(_plotter))
-     S___(Plotter *_plotter;)
-#endif
+_pl_f_paint_point (S___(Plotter *_plotter))
 {
   double x, y;
   
@@ -28,8 +41,8 @@ _f_paint_point (S___(_plotter))
     /* have a pen to draw with */
     {
       /* evaluate fig colors lazily, i.e. only when needed */
-      _f_set_pen_color (S___(_plotter));
-      _f_set_fill_color (S___(_plotter));
+      _pl_f_set_pen_color (S___(_plotter));
+      _pl_f_set_fill_color (S___(_plotter));
       
       /* update xfig's `depth' attribute */
       if (_plotter->fig_drawing_depth > 0)
