@@ -1,3 +1,21 @@
+/* This file is part of the GNU plotutils package.  Copyright (C) 1995,
+   1996, 1997, 1998, 1999, 2000, 2005, Free Software Foundation, Inc.
+
+   The GNU plotutils package is free software.  You may redistribute it
+   and/or modify it under the terms of the GNU General Public License as
+   published by the Free Software foundation; either version 2, or (at your
+   option) any later version.
+
+   The GNU plotutils package is distributed in the hope that it will be
+   useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License along
+   with the GNU plotutils package; see the file COPYING.  If not, write to
+   the Free Software Foundation, Inc., 51 Franklin St., Fifth Floor,
+   Boston, MA 02110-1301, USA. */
+
 /* This file contains the Fig-driver-specific version of the low-level
    paint_text_string() method, which is called to plot a label in the
    current PS font, at the current fontsize and textangle.  The label is
@@ -23,22 +41,15 @@
 #define FIG_ALIGN_LEFT 0
 #define FIG_ALIGN_CENTER 1
 #define FIG_ALIGN_RIGHT 2
-static const int _fig_horizontal_alignment_style[] =
+static const int fig_horizontal_alignment_style[PL_NUM_HORIZ_JUST_TYPES] =
 { FIG_ALIGN_LEFT, FIG_ALIGN_CENTER, FIG_ALIGN_RIGHT };
 
 /* This prints a single-font, single-font-size label.  When this is called,
    the current point is on the intended baseline of the label.  */
 
+/* ARGS: h_just,v_just are PL_JUST_{LEFT|CENTER|RIGHT}, PL_JUST_{TOP etc.} */
 double
-#ifdef _HAVE_PROTOS
-_f_paint_text_string (R___(Plotter *_plotter) const unsigned char *s, int h_just, int v_just)
-#else
-_f_paint_text_string (R___(_plotter) s, h_just, v_just)
-     S___(Plotter *_plotter;)
-     const unsigned char *s;
-     int h_just;  /* horizontal justification: JUST_LEFT, CENTER, or RIGHT */
-     int v_just;  /* vertical justification: JUST_TOP, HALF, BASE, BOTTOM */
-#endif
+_pl_f_paint_text_string (R___(Plotter *_plotter) const unsigned char *s, int h_just, int v_just)
 {
   int len, master_font_index;
   unsigned char *ptr, *t;
@@ -52,11 +63,11 @@ _f_paint_text_string (R___(_plotter) s, h_just, v_just)
   double angle_device;
   
   /* sanity check */
-  if (_plotter->drawstate->font_type != F_POSTSCRIPT)
+  if (_plotter->drawstate->font_type != PL_F_POSTSCRIPT)
     return 0.0;
 
   /* sanity check; this routine supports only baseline positioning */
-  if (v_just != JUST_BASE)
+  if (v_just != PL_JUST_BASE)
     return 0.0;
 
   /* if empty string, nothing to do */
@@ -76,11 +87,11 @@ _f_paint_text_string (R___(_plotter) s, h_just, v_just)
 
   /* compute index of font in master table of PS fonts, in g_fontdb.h */
   master_font_index =
-    (_ps_typeface_info[_plotter->drawstate->typeface_index].fonts)[_plotter->drawstate->font_index];
+    (_pl_g_ps_typeface_info[_plotter->drawstate->typeface_index].fonts)[_plotter->drawstate->font_index];
 
   /* compute label height and width, in user units */
   label_width = _plotter->get_text_width (R___(_plotter) s);
-  label_ascent  = _plotter->drawstate->true_font_size * (_ps_font_info[master_font_index]).font_ascent / 1000.0;
+  label_ascent  = _plotter->drawstate->true_font_size * (_pl_g_ps_font_info[master_font_index]).font_ascent / 1000.0;
   
   /* vector along baseline of label, and an orthogonal vector which is the
      other side of a rectangle containing the portion of the string above
@@ -129,11 +140,11 @@ _f_paint_text_string (R___(_plotter) s, h_just, v_just)
   initial_y = YD((_plotter->drawstate->pos).x, (_plotter->drawstate->pos).y);
 
   /* evaluate fig colors lazily, i.e. only when needed */
-  _f_set_pen_color (S___(_plotter));
+  _pl_f_set_pen_color (S___(_plotter));
   
   /* escape all backslashes in the text string, before output */
   len = strlen ((char *)s);
-  ptr = (unsigned char *)_plot_xmalloc ((4 * len + 1) * sizeof(char));
+  ptr = (unsigned char *)_pl_xmalloc ((4 * len + 1) * sizeof(char));
   t = ptr;
   while (*s)
     {
@@ -165,11 +176,11 @@ _f_paint_text_string (R___(_plotter) s, h_just, v_just)
 	  "#TEXT\n%d %d %d %d %d %d %.3f %.3f %d %.3f %.3f %d %d %s\\001\n",
 	  4,			/* text object */
 	  /* xfig supports 3 justification types: left, center, or right. */
-	  _fig_horizontal_alignment_style[h_just],/* horizontal just. type */
+	  fig_horizontal_alignment_style[h_just],/* horizontal just. type */
 	  _plotter->drawstate->fig_fgcolor, /* pen color */
 	  _plotter->fig_drawing_depth, /* depth */
 	  0,			/* pen style, ignored */
-	  _ps_font_info[master_font_index].fig_id, /* Fig font id */
+	  _pl_g_ps_font_info[master_font_index].fig_id, /* Fig font id */
 	  (double)_plotter->drawstate->fig_font_point_size, /* point size (float) */
 	  angle_device,		/* text rotation in radians (float) */
 	  FONT_TYPE_PS,		/* Fig font type */
