@@ -1,3 +1,21 @@
+/* This file is part of the GNU plotutils package.  Copyright (C) 1995,
+   1996, 1997, 1998, 1999, 2000, 2005, Free Software Foundation, Inc.
+
+   The GNU plotutils package is free software.  You may redistribute it
+   and/or modify it under the terms of the GNU General Public License as
+   published by the Free Software foundation; either version 2, or (at your
+   option) any later version.
+
+   The GNU plotutils package is distributed in the hope that it will be
+   useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License along
+   with the GNU plotutils package; see the file COPYING.  If not, write to
+   the Free Software Foundation, Inc., 51 Franklin St., Fifth Floor,
+   Boston, MA 02110-1301, USA. */
+
 /* This file contains the translate, rotate and scale methods, which are
    GNU extensions to libplot.  They affect the affine transformation from
    user coordinates to device coordinates, as in Postscript. */
@@ -6,13 +24,7 @@
 #include "extern.h"
 
 int
-#ifdef _HAVE_PROTOS
 _API_ftranslate (R___(Plotter *_plotter) double x, double y)
-#else
-_API_ftranslate (R___(_plotter) x, y)
-     S___(Plotter *_plotter;)
-     double x, y;
-#endif
 {
   double m0, m1, m2, m3, m4, m5;
 
@@ -33,13 +45,7 @@ _API_ftranslate (R___(_plotter) x, y)
 }
 
 int
-#ifdef _HAVE_PROTOS
 _API_frotate (R___(Plotter *_plotter) double theta)
-#else
-_API_frotate (R___(_plotter) theta)
-     S___(Plotter *_plotter;)
-     double theta;
-#endif
 {
   double m0, m1, m2, m3, m4, m5;
   double radians = M_PI * theta / 180.0;
@@ -61,13 +67,7 @@ _API_frotate (R___(_plotter) theta)
 }
 
 int
-#ifdef _HAVE_PROTOS
 _API_fscale (R___(Plotter *_plotter) double x, double y)
-#else
-_API_fscale (R___(_plotter) x, y)
-     S___(Plotter *_plotter;)
-     double x, y;
-#endif
 {
   double m0, m1, m2, m3, m4, m5;
 
