@@ -1,10 +1,29 @@
-/* This file contains the internal method _alabel_hershey(), which plots a
-   label using Hershey fonts.  Each character in a Hershey font is a
-   sequence of pen motions, so this function calls _API_fmoverel() and
+/* This file is part of the GNU plotutils package.  Copyright (C) 1995,
+   1996, 1997, 1998, 1999, 2000, 2005, Free Software Foundation, Inc.
+
+   The GNU plotutils package is free software.  You may redistribute it
+   and/or modify it under the terms of the GNU General Public License as
+   published by the Free Software foundation; either version 2, or (at your
+   option) any later version.
+
+   The GNU plotutils package is distributed in the hope that it will be
+   useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License along
+   with the GNU plotutils package; see the file COPYING.  If not, write to
+   the Free Software Foundation, Inc., 51 Franklin St., Fifth Floor,
+   Boston, MA 02110-1301, USA. */
+
+/* This file contains the internal method _pl_g_alabel_hershey(), which
+   plots a label using Hershey fonts.  Each character in a Hershey font is
+   a sequence of pen motions, so this function calls _API_fmoverel() and
    _API_fcontrel() to `stroke' each character in the argument string.
 
    The width of the string in user units is returned.  The internal method
-   _flabelwidth_hershey() is similar, but does not actually plot the label.  */
+   _pl_g_flabelwidth_hershey() is similar, but does not actually plot the
+   label.  */
 
 #include "sys-defines.h"
 #include "extern.h"
@@ -46,21 +65,14 @@
 #define BEGINNING_OF_KANA 4195
 
 /* forward references */
-static bool _composite_char ____P((unsigned char *composite, unsigned char *character, unsigned char *accent));
-static double _label_width_hershey ____P((const unsigned short *label));
+static bool composite_char (unsigned char *composite, unsigned char *character, unsigned char *accent);
+static double label_width_hershey (const unsigned short *label);
 
 /* An version of the alabel() method that is specific to the case when the
    current Plotter font is a Hershey font.  It handles escape sequences for
    subscripts, superscripts, shifts among Hershey fonts, etc.  */
 double
-#ifdef _HAVE_PROTOS
-_alabel_hershey (R___(Plotter *_plotter) const unsigned char *s, int x_justify, int y_justify)
-#else
-_alabel_hershey (R___(_plotter) s, x_justify, y_justify)
-     S___(Plotter *_plotter;)
-     const unsigned char *s;
-     int x_justify, y_justify;
-#endif
+_pl_g_alabel_hershey (R___(Plotter *_plotter) const unsigned char *s, int x_justify, int y_justify)
 {
   unsigned short *codestring;
   char x_justify_c, y_justify_c;
@@ -71,10 +83,10 @@ _alabel_hershey (R___(_plotter) s, x_justify, y_justify)
   double theta;
 
   /* convert string to a codestring, including annotations */
-  codestring = _controlify (R___(_plotter) s);
+  codestring = _pl_g_controlify (R___(_plotter) s);
 
   /* dimensions of the string in user units */
-  label_width = HERSHEY_UNITS_TO_USER_UNITS(_label_width_hershey (codestring));
+  label_width = HERSHEY_UNITS_TO_USER_UNITS(label_width_hershey (codestring));
   label_height = HERSHEY_UNITS_TO_USER_UNITS(HERSHEY_HEIGHT);
   
   x_justify_c = (char)x_justify;
@@ -131,9 +143,9 @@ _alabel_hershey (R___(_plotter) s, x_justify, y_justify)
     double oldposx, oldposy;
     bool old_dash_array_in_effect;
 
-    old_line_mode = (char *)_plot_xmalloc (strlen (_plotter->drawstate->line_mode) + 1);
-    old_cap_mode = (char *)_plot_xmalloc (strlen (_plotter->drawstate->cap_mode) + 1);
-    old_join_mode = (char *)_plot_xmalloc (strlen (_plotter->drawstate->join_mode) + 1);
+    old_line_mode = (char *)_pl_xmalloc (strlen (_plotter->drawstate->line_mode) + 1);
+    old_cap_mode = (char *)_pl_xmalloc (strlen (_plotter->drawstate->cap_mode) + 1);
+    old_join_mode = (char *)_pl_xmalloc (strlen (_plotter->drawstate->join_mode) + 1);
     oldposx = _plotter->drawstate->pos.x;
     oldposy = _plotter->drawstate->pos.y;    
 
@@ -170,7 +182,7 @@ _alabel_hershey (R___(_plotter) s, x_justify, y_justify)
     
     /* call stroker on the sequence of strokes obtained from each char (the
        stroker may manipulate the line width) */
-    _draw_hershey_string (R___(_plotter) codestring);
+    _pl_g_draw_hershey_string (R___(_plotter) codestring);
     
     /* Restore original values of relevant drawing attributes, free
        storage.  endpath() will be invoked in here automatically, flushing
@@ -205,39 +217,26 @@ _alabel_hershey (R___(_plotter) s, x_justify, y_justify)
 /* A version of the flabelwidth() method that is specific to the case when
    the current Plotter font is a Hershey font. */
 double
-#ifdef _HAVE_PROTOS
-_flabelwidth_hershey (R___(Plotter *_plotter) const unsigned char *s)
-#else
-_flabelwidth_hershey (R___(_plotter) s)
-     S___(Plotter *_plotter;)
-     const unsigned char *s;
-#endif
+_pl_g_flabelwidth_hershey (R___(Plotter *_plotter) const unsigned char *s)
 {
   double label_width;
   unsigned short *codestring;
   
   /* convert string to a codestring, including annotations */
-  codestring = _controlify (R___(_plotter) s);
+  codestring = _pl_g_controlify (R___(_plotter) s);
 
-  label_width = HERSHEY_UNITS_TO_USER_UNITS(_label_width_hershey (codestring));
+  label_width = HERSHEY_UNITS_TO_USER_UNITS(label_width_hershey (codestring));
   free (codestring);
   
   return label_width;
 }
 
-/* _draw_hershey_stroke() draws a stroke, taking into account the
+/* _pl_g_draw_hershey_stroke() draws a stroke, taking into account the
    transformation from Hershey units to user units, and also the angle in
    user space at which the label should be plotted. */
 
 void
-#ifdef _HAVE_PROTOS
-_draw_hershey_stroke (R___(Plotter *_plotter) bool pendown, double deltax, double deltay)
-#else
-_draw_hershey_stroke (R___(_plotter) pendown, deltax, deltay)
-     S___(Plotter *_plotter;)
-     bool pendown;
-     double deltax, deltay;
-#endif
+_pl_g_draw_hershey_stroke (R___(Plotter *_plotter) bool pendown, double deltax, double deltay)
 {
   double theta = M_PI * _plotter->drawstate->text_rotation / 180.0;
   double dx, dy;
@@ -254,7 +253,7 @@ _draw_hershey_stroke (R___(_plotter) pendown, deltax, deltay)
     _API_fmoverel (R___(_plotter) dx, dy);
 }
 
-/* _label_width_hershey() computes the width (total delta x) of a
+/* label_width_hershey() computes the width (total delta x) of a
    controlified character string to be rendered in a vector font, in
    Hershey units.  Parsing must take into account the many control
    sequences which perform shifts, and initiate/terminate
@@ -276,12 +275,7 @@ _draw_hershey_stroke (R___(_plotter) pendown, deltax, deltay)
    the +1/6's here were +2/9 instead.  Better?] */
 
 static double
-#ifdef _HAVE_PROTOS
-_label_width_hershey (const unsigned short *label) 
-#else
-_label_width_hershey (label) 
-     const unsigned short *label;
-#endif
+label_width_hershey (const unsigned short *label) 
 { 
   const unsigned short *ptr = label;
   unsigned short c;
@@ -300,7 +294,7 @@ _label_width_hershey (label)
 	/* glyph was spec'd via an escape, not as a char in a font */
 	{
 	  glyphnum = c & GLYPH_SPEC;
-	  glyph = (const unsigned char *)(_occidental_hershey_glyphs[glyphnum]);
+	  glyph = (const unsigned char *)(_pl_g_occidental_hershey_glyphs[glyphnum]);
 	  
 	  if (*glyph != '\0')	/* nonempty glyph */
 	    /* 1st two chars are bounds */
@@ -310,7 +304,7 @@ _label_width_hershey (label)
 	/* glyph was spec'd via an escape, not as a char in a font */
 	{
 	  glyphnum = c & GLYPH_SPEC;
-	  glyph = (const unsigned char *)_oriental_hershey_glyphs[glyphnum];
+	  glyph = (const unsigned char *)_pl_g_oriental_hershey_glyphs[glyphnum];
 	  
 	  if (*glyph != '\0')	/* nonempty glyph */
 	    /* 1st two chars are bounds */
@@ -401,7 +395,7 @@ _label_width_hershey (label)
 	  raw_fontnum = (c >> FONT_SHIFT) & ONE_BYTE;
 	  
 	  c &= ~FONT_SPEC;	/* extract character proper */
-	  glyphnum = (_hershey_font_info[raw_fontnum].chars)[c];
+	  glyphnum = (_pl_g_hershey_font_info[raw_fontnum].chars)[c];
 
 	  /* could be a pseudo glyph number, e.g. an indication that
 	     character is composite */
@@ -411,8 +405,8 @@ _label_width_hershey (label)
 
 	      /* if so, use 1st element of composite character */
 	      composite = (unsigned char)c;
-	      if (_composite_char (&composite, &character, &accent))
-		glyphnum = (_hershey_font_info[raw_fontnum].chars)[character];
+	      if (composite_char (&composite, &character, &accent))
+		glyphnum = (_pl_g_hershey_font_info[raw_fontnum].chars)[character];
 	      else
 		glyphnum = UNDE; /* hope this won't happen */
 	    }
@@ -422,7 +416,7 @@ _label_width_hershey (label)
 	  if (glyphnum & KS)
 	    glyphnum -= KS;
 
-	  glyph = (const unsigned char *)(_occidental_hershey_glyphs[glyphnum]);
+	  glyph = (const unsigned char *)(_pl_g_occidental_hershey_glyphs[glyphnum]);
 	  if (*glyph != '\0')	/* nonempty glyph */
 	    /* 1st two chars are bounds */
 	    width += charsize * ((int)glyph[1] - (int)glyph[0]);
@@ -434,44 +428,27 @@ _label_width_hershey (label)
   return width;
 }  
 
-/* _draw_hershey_penup_stroke() draws a penup stroke, along a vector
+/* _pl_g_draw_hershey_penup_stroke() draws a penup stroke, along a vector
    specified in Hershey units.  Size scaling and obliquing (true/false) are
-   specified.  This is used for repositioning during rendering of
-   composite (accented) characters. */
+   specified.  This is used for repositioning during rendering of composite
+   (accented) characters. */
 void
-#ifdef _HAVE_PROTOS
-_draw_hershey_penup_stroke(R___(Plotter *_plotter) double dx, double dy, double charsize, bool oblique)
-#else
-_draw_hershey_penup_stroke(R___(_plotter) dx, dy, charsize, oblique)
-     S___(Plotter *_plotter;)
-     double dx, dy;
-     double charsize;
-     bool oblique;
-#endif
+_pl_g_draw_hershey_penup_stroke(R___(Plotter *_plotter) double dx, double dy, double charsize, bool oblique)
 {
   double shear;
 
   shear = oblique ? (SHEAR) : 0.0;
-  _draw_hershey_stroke (R___(_plotter)
-			false,	/* pen up */
-			charsize * (dx + shear * dy), 
-			charsize * dy);
+  _pl_g_draw_hershey_stroke (R___(_plotter)
+			     false, /* pen up */
+			     charsize * (dx + shear * dy), 
+			     charsize * dy);
 }
 
-/* _draw_hershey_glyph() invokes move() and cont() to draw a raw Hershey
-   glyph, specified by index in the occidental or oriental glyph arrays.
-   Size scaling and obliquing (true/false) are specified. */
+/* _pl_g_draw_hershey_glyph() invokes move() and cont() to draw a raw
+   Hershey glyph, specified by index in the occidental or oriental glyph
+   arrays.  Size scaling and obliquing (true/false) are specified. */
 void
-#ifdef _HAVE_PROTOS
-_draw_hershey_glyph (R___(Plotter *_plotter) int glyphnum, double charsize, int type, bool oblique)
-#else
-_draw_hershey_glyph (R___(_plotter) glyphnum, charsize, type, oblique)
-     S___(Plotter *_plotter;)
-     int glyphnum;
-     double charsize;
-     int type;
-     bool oblique;
-#endif
+_pl_g_draw_hershey_glyph (R___(Plotter *_plotter) int glyphnum, double charsize, int type, bool oblique)
 {
   double xcurr, ycurr;
   double xfinal, yfinal;
@@ -485,10 +462,10 @@ _draw_hershey_glyph (R___(_plotter) glyphnum, charsize, type, oblique)
     {
     case OCCIDENTAL:
     default:
-      glyph = (const unsigned char *)(_occidental_hershey_glyphs[glyphnum]);
+      glyph = (const unsigned char *)(_pl_g_occidental_hershey_glyphs[glyphnum]);
       break;
     case ORIENTAL:
-      glyph = (const unsigned char *)(_oriental_hershey_glyphs[glyphnum]); 
+      glyph = (const unsigned char *)(_pl_g_oriental_hershey_glyphs[glyphnum]); 
       break;
     }
 
@@ -516,8 +493,8 @@ _draw_hershey_glyph (R___(_plotter) glyphnum, charsize, type, oblique)
 		   - ((int)glyph[1] + (double)HERSHEY_BASELINE));
 	      dx = xnew - xcurr;
 	      dy = ynew - ycurr;
-	      _draw_hershey_stroke (R___(_plotter) 
-				    pendown, dx + shear * dy, dy);
+	      _pl_g_draw_hershey_stroke (R___(_plotter) 
+					 pendown, dx + shear * dy, dy);
 	      xcurr = xnew, ycurr = ynew;
 	      pendown = true;
 	    }
@@ -528,21 +505,15 @@ _draw_hershey_glyph (R___(_plotter) glyphnum, charsize, type, oblique)
       /* final penup stroke, to end where we should */
       dx = xfinal - xcurr;
       dy = yfinal - ycurr;
-      _draw_hershey_stroke (R___(_plotter) false, dx + shear * dy, dy);
+      _pl_g_draw_hershey_stroke (R___(_plotter) false, dx + shear * dy, dy);
     }
 }
 
-/* _draw_hershey_string() strokes a string beginning at present location,
-   which is taken to be on the string's baseline.  Besides invoking move()
-   and cont(), it invokes linewidth(). */
+/* _pl_g_draw_hershey_string() strokes a string beginning at present
+   location, which is taken to be on the string's baseline.  Besides
+   invoking move() and cont(), it invokes linewidth(). */
 void
-#ifdef _HAVE_PROTOS
-_draw_hershey_string (R___(Plotter *_plotter) const unsigned short *string)
-#else
-_draw_hershey_string (R___(_plotter) string)
-     S___(Plotter *_plotter;)
-     const unsigned short *string;
-#endif
+_pl_g_draw_hershey_string (R___(Plotter *_plotter) const unsigned short *string)
 {
   unsigned short c;
   const unsigned short *ptr = string;
@@ -572,8 +543,8 @@ _draw_hershey_string (R___(_plotter) string)
 				    HERSHEY_UNITS_TO_USER_UNITS (HERSHEY_STROKE_WIDTH));
 	      line_width_type = 1;
 	    }
-	  _draw_hershey_glyph (R___(_plotter)
-			       c & GLYPH_SPEC, charsize, OCCIDENTAL, false);
+	  _pl_g_draw_hershey_glyph (R___(_plotter)
+				    c & GLYPH_SPEC, charsize, OCCIDENTAL, false);
 	}
 
       else if (c & RAW_ORIENTAL_HERSHEY_GLYPH)
@@ -584,43 +555,43 @@ _draw_hershey_string (R___(_plotter) string)
 				    HERSHEY_UNITS_TO_USER_UNITS (HERSHEY_ORIENTAL_STROKE_WIDTH));
 	      line_width_type = 2;
 	    }
-	  _draw_hershey_glyph (R___(_plotter)
-			       c & GLYPH_SPEC, charsize, ORIENTAL, false);
+	  _pl_g_draw_hershey_glyph (R___(_plotter)
+				    c & GLYPH_SPEC, charsize, ORIENTAL, false);
 	}
 
       else if (c & CONTROL_CODE)	
 	switch (c & ~CONTROL_CODE) /* parse control codes */
 	  {
 	  case C_BEGIN_SUPERSCRIPT :
-	    _draw_hershey_stroke (R___(_plotter)
-				  false, 
-				  SUPERSCRIPT_DX * charsize * HERSHEY_EM,
-				  SUPERSCRIPT_DY * charsize * HERSHEY_EM);
+	    _pl_g_draw_hershey_stroke (R___(_plotter)
+				       false, 
+				       SUPERSCRIPT_DX * charsize * HERSHEY_EM,
+				       SUPERSCRIPT_DY * charsize * HERSHEY_EM);
 	    charsize *= SCRIPTSIZE;
 	    break;
 		
 	  case C_END_SUPERSCRIPT:
 	    charsize /= SCRIPTSIZE;
-	    _draw_hershey_stroke (R___(_plotter)
-				  false, 
-				  - SUPERSCRIPT_DX * charsize * HERSHEY_EM,
-				  - SUPERSCRIPT_DY * charsize * HERSHEY_EM);
+	    _pl_g_draw_hershey_stroke (R___(_plotter)
+				       false, 
+				       - SUPERSCRIPT_DX * charsize * HERSHEY_EM,
+				       - SUPERSCRIPT_DY * charsize * HERSHEY_EM);
 	    break;
 		
 	  case C_BEGIN_SUBSCRIPT:
-	    _draw_hershey_stroke (R___(_plotter)
-				  false, 
-				  SUBSCRIPT_DX * charsize * HERSHEY_EM,
-				  SUBSCRIPT_DY * charsize * HERSHEY_EM);
+	    _pl_g_draw_hershey_stroke (R___(_plotter)
+				       false, 
+				       SUBSCRIPT_DX * charsize * HERSHEY_EM,
+				       SUBSCRIPT_DY * charsize * HERSHEY_EM);
 	    charsize *= SCRIPTSIZE;
 	    break;
 		
 	  case C_END_SUBSCRIPT:
 	    charsize /= SCRIPTSIZE;
-	    _draw_hershey_stroke (R___(_plotter)
-				  false, 
-				  - SUBSCRIPT_DX * charsize * HERSHEY_EM,
-				  - SUBSCRIPT_DY * charsize * HERSHEY_EM);
+	    _pl_g_draw_hershey_stroke (R___(_plotter)
+				       false, 
+				       - SUBSCRIPT_DX * charsize * HERSHEY_EM,
+				       - SUBSCRIPT_DY * charsize * HERSHEY_EM);
 	    break;
 		
 	  case C_PUSH_LOCATION:
@@ -636,63 +607,63 @@ _draw_hershey_string (R___(_plotter) string)
 	    break;
 		
 	  case C_RIGHT_ONE_EM:
-	    _draw_hershey_stroke (R___(_plotter)
-				  false, charsize * HERSHEY_EM, 0.0);
+	    _pl_g_draw_hershey_stroke (R___(_plotter)
+				       false, charsize * HERSHEY_EM, 0.0);
 	    break;
 		
 	  case C_RIGHT_HALF_EM:
-	    _draw_hershey_stroke (R___(_plotter)
-				  false, charsize * HERSHEY_EM / 2.0, 0.0);
+	    _pl_g_draw_hershey_stroke (R___(_plotter)
+				       false, charsize * HERSHEY_EM / 2.0, 0.0);
 	    break;
 		
 	  case C_RIGHT_QUARTER_EM:
-	    _draw_hershey_stroke (R___(_plotter)
-				  false, charsize * HERSHEY_EM / 4.0, 0.0);
+	    _pl_g_draw_hershey_stroke (R___(_plotter)
+				       false, charsize * HERSHEY_EM / 4.0, 0.0);
 	    break;
 		
 	  case C_RIGHT_SIXTH_EM:
-	    _draw_hershey_stroke (R___(_plotter)
-				  false, charsize * HERSHEY_EM / 6.0, 0.0);
+	    _pl_g_draw_hershey_stroke (R___(_plotter)
+				       false, charsize * HERSHEY_EM / 6.0, 0.0);
 	    break;
 		
 	  case C_RIGHT_EIGHTH_EM:
-	    _draw_hershey_stroke (R___(_plotter)
-				  false, charsize * HERSHEY_EM / 8.0, 0.0);
+	    _pl_g_draw_hershey_stroke (R___(_plotter)
+				       false, charsize * HERSHEY_EM / 8.0, 0.0);
 	    break;
 		
 	  case C_RIGHT_TWELFTH_EM:
-	    _draw_hershey_stroke (R___(_plotter)
-				  false, charsize * HERSHEY_EM / 12.0, 0.0);
+	    _pl_g_draw_hershey_stroke (R___(_plotter)
+				       false, charsize * HERSHEY_EM / 12.0, 0.0);
 	    break;
 		
 	  case C_LEFT_ONE_EM:
-	    _draw_hershey_stroke (R___(_plotter)
-				  false, - charsize * HERSHEY_EM, 0.0);
+	    _pl_g_draw_hershey_stroke (R___(_plotter)
+				       false, - charsize * HERSHEY_EM, 0.0);
 	    break;
 		
 	  case C_LEFT_HALF_EM:
-	    _draw_hershey_stroke (R___(_plotter)
-				  false, - charsize * HERSHEY_EM / 2.0, 0.0);
+	    _pl_g_draw_hershey_stroke (R___(_plotter)
+				       false, - charsize * HERSHEY_EM / 2.0, 0.0);
 	    break;
 		
 	  case C_LEFT_QUARTER_EM:
-	    _draw_hershey_stroke (R___(_plotter)
-				  false, - charsize * HERSHEY_EM / 4.0, 0.0);
+	    _pl_g_draw_hershey_stroke (R___(_plotter)
+				       false, - charsize * HERSHEY_EM / 4.0, 0.0);
 	    break;
 		
 	  case C_LEFT_SIXTH_EM:
-	    _draw_hershey_stroke (R___(_plotter)
-				  false, - charsize * HERSHEY_EM / 6.0, 0.0);
+	    _pl_g_draw_hershey_stroke (R___(_plotter)
+				       false, - charsize * HERSHEY_EM / 6.0, 0.0);
 	    break;
 		
 	  case C_LEFT_EIGHTH_EM:
-	    _draw_hershey_stroke (R___(_plotter)
-				  false, - charsize * HERSHEY_EM / 8.0, 0.0);
+	    _pl_g_draw_hershey_stroke (R___(_plotter)
+				       false, - charsize * HERSHEY_EM / 8.0, 0.0);
 	    break;
 
 	  case C_LEFT_TWELFTH_EM:
-	    _draw_hershey_stroke (R___(_plotter)
-				  false, - charsize * HERSHEY_EM / 12.0, 0.0);
+	    _pl_g_draw_hershey_stroke (R___(_plotter)
+				       false, - charsize * HERSHEY_EM / 12.0, 0.0);
 	    break;
 		
 	    /* unrecognized control code, punt */
@@ -716,10 +687,10 @@ _draw_hershey_string (R___(_plotter) string)
 	  /* compute index of font, in font table in g_fontdb.c */
 	  raw_fontnum = (c >> FONT_SHIFT) & ONE_BYTE;
 	  /* shear font?  (for HersheySans-Oblique, etc.) */
-	  oblique = _hershey_font_info[raw_fontnum].obliquing;
+	  oblique = _pl_g_hershey_font_info[raw_fontnum].obliquing;
 	  
 	  c &= ~FONT_SPEC;	/* extract character proper */
-	  glyphnum = (_hershey_font_info[raw_fontnum].chars)[c];
+	  glyphnum = (_pl_g_hershey_font_info[raw_fontnum].chars)[c];
 	  
 	  if (glyphnum & KS) /* a small kana? */
 	    {
@@ -735,12 +706,12 @@ _draw_hershey_string (R___(_plotter) string)
 	    case ACC1:
 	    case ACC2:
 	      composite = (unsigned char)c;
-	      if (_composite_char (&composite, &character, &accent))
+	      if (composite_char (&composite, &character, &accent))
 		{
 		  char_glyphnum = 
-		    (_hershey_font_info[raw_fontnum].chars)[character];
+		    (_pl_g_hershey_font_info[raw_fontnum].chars)[character];
 		  accent_glyphnum = 
-		    (_hershey_font_info[raw_fontnum].chars)[accent];
+		    (_pl_g_hershey_font_info[raw_fontnum].chars)[accent];
 		}
 	      else
 		{		/* hope this won't happen */
@@ -748,9 +719,9 @@ _draw_hershey_string (R___(_plotter) string)
 		  accent_glyphnum = 0;
 		}
 	      char_glyph = 
-		(const unsigned char *)_occidental_hershey_glyphs[char_glyphnum];
+		(const unsigned char *)_pl_g_occidental_hershey_glyphs[char_glyphnum];
 	      accent_glyph = 
-		(const unsigned char *)_occidental_hershey_glyphs[accent_glyphnum];
+		(const unsigned char *)_pl_g_occidental_hershey_glyphs[accent_glyphnum];
 	  
 	      if (*char_glyph != '\0') /* nonempty glyph */
 		/* 1st two chars are bounds, in Hershey units */
@@ -771,49 +742,49 @@ _draw_hershey_string (R___(_plotter) string)
 					HERSHEY_UNITS_TO_USER_UNITS (HERSHEY_STROKE_WIDTH));
 		  line_width_type = 1;
 		}
-	      _draw_hershey_glyph (R___(_plotter)
-				   char_glyphnum, charsize, 
-				   OCCIDENTAL, oblique);
+	      _pl_g_draw_hershey_glyph (R___(_plotter)
+					char_glyphnum, charsize, 
+					OCCIDENTAL, oblique);
 	      /* back up to draw accent */
-	      _draw_hershey_penup_stroke (R___(_plotter)
-					  -0.5 * (double)char_width
-					  -0.5 * (double)accent_width,
-					  0.0, charsize, oblique);
+	      _pl_g_draw_hershey_penup_stroke (R___(_plotter)
+					       -0.5 * (double)char_width
+					       -0.5 * (double)accent_width,
+					       0.0, charsize, oblique);
 
 	      /* repositioning for uppercase and uppercase italic */
 	      if (glyphnum == ACC1)
-		_draw_hershey_penup_stroke (R___(_plotter)
-					    0.0, 
-					    (double)(ACCENT_UP_SHIFT),
-					    charsize, oblique);
+		_pl_g_draw_hershey_penup_stroke (R___(_plotter)
+						 0.0, 
+						 (double)(ACCENT_UP_SHIFT),
+						 charsize, oblique);
 	      else if (glyphnum == ACC2)
-		_draw_hershey_penup_stroke (R___(_plotter)
-					    (double)(ACCENT_RIGHT_SHIFT),
-					    (double)(ACCENT_UP_SHIFT),
-					    charsize, oblique);
+		_pl_g_draw_hershey_penup_stroke (R___(_plotter)
+						 (double)(ACCENT_RIGHT_SHIFT),
+						 (double)(ACCENT_UP_SHIFT),
+						 charsize, oblique);
 
 	      /* draw the accent */
-	      _draw_hershey_glyph (R___(_plotter)
-				   accent_glyphnum, charsize, 
-				   OCCIDENTAL, oblique);
+	      _pl_g_draw_hershey_glyph (R___(_plotter)
+					accent_glyphnum, charsize, 
+					OCCIDENTAL, oblique);
 
 	      /* undo special repositioning if any */
 	      if (glyphnum == ACC1)
-		_draw_hershey_penup_stroke (R___(_plotter)
-					    0.0, 
-					    -(double)(ACCENT_UP_SHIFT),
-					    charsize, oblique);
+		_pl_g_draw_hershey_penup_stroke (R___(_plotter)
+						 0.0, 
+						 -(double)(ACCENT_UP_SHIFT),
+						 charsize, oblique);
 	      else if (glyphnum == ACC2)
-		_draw_hershey_penup_stroke (R___(_plotter)
-					    -(double)(ACCENT_RIGHT_SHIFT),
-					    -(double)(ACCENT_UP_SHIFT),
-					    charsize, oblique);
+		_pl_g_draw_hershey_penup_stroke (R___(_plotter)
+						 -(double)(ACCENT_RIGHT_SHIFT),
+						 -(double)(ACCENT_UP_SHIFT),
+						 charsize, oblique);
 
 	      /* move forward, to end composite char where we should */
-	      _draw_hershey_penup_stroke (R___(_plotter)
-					  0.5 * (double)char_width
-					  -0.5 * (double)accent_width,
-					  0.0, charsize, oblique);
+	      _pl_g_draw_hershey_penup_stroke (R___(_plotter)
+					       0.5 * (double)char_width
+					       -0.5 * (double)accent_width,
+					       0.0, charsize, oblique);
 	      break;
 
 	      /* not a composite (accented) character; just an ordinary
@@ -827,28 +798,28 @@ _draw_hershey_string (R___(_plotter) string)
 		  double shift = 0.5 * (1.0 - (SMALL_KANA_SIZE));
 
 		  kana_glyph = 
-		    (const unsigned char *)_occidental_hershey_glyphs[glyphnum];
+		    (const unsigned char *)_pl_g_occidental_hershey_glyphs[glyphnum];
 		  kana_width = (int)kana_glyph[1] - (int)kana_glyph[0];
 
 		  /* draw small Kana, preceded and followed by a penup
 		     stroke in order to traverse the full width of an
 		     ordinary Kana */
-		  _draw_hershey_penup_stroke (R___(_plotter)
-					      shift * (double)kana_width,
-					      0.0, charsize, oblique);
+		  _pl_g_draw_hershey_penup_stroke (R___(_plotter)
+						   shift * (double)kana_width,
+						   0.0, charsize, oblique);
 		  if (line_width_type != 2)
 		    {
 		      _API_flinewidth (R___(_plotter)
 					    HERSHEY_UNITS_TO_USER_UNITS (HERSHEY_ORIENTAL_STROKE_WIDTH));
 		      line_width_type = 2;
 		    }
-		  _draw_hershey_glyph (R___(_plotter)
-				       glyphnum, 
-				       (SMALL_KANA_SIZE) * charsize,
-				       OCCIDENTAL, oblique);
-		  _draw_hershey_penup_stroke (R___(_plotter)
-					      shift * (double)kana_width,
-					      0.0, charsize, oblique);
+		  _pl_g_draw_hershey_glyph (R___(_plotter)
+					    glyphnum, 
+					    (SMALL_KANA_SIZE) * charsize,
+					    OCCIDENTAL, oblique);
+		  _pl_g_draw_hershey_penup_stroke (R___(_plotter)
+						   shift * (double)kana_width,
+						   0.0, charsize, oblique);
 		}
 	      else
 		/* whew! just an ordinary glyph from the occidental array
@@ -871,9 +842,9 @@ _draw_hershey_string (R___(_plotter) string)
 						HERSHEY_UNITS_TO_USER_UNITS (HERSHEY_STROKE_WIDTH));
 			  line_width_type = 1;
 			}
-		_draw_hershey_glyph (R___(_plotter)
-				     glyphnum, charsize, 
-				     OCCIDENTAL, oblique);
+		_pl_g_draw_hershey_glyph (R___(_plotter)
+					  glyphnum, charsize, 
+					  OCCIDENTAL, oblique);
 		}
 	      break;
 	    } /* end of case statement that switches based on glyphnum */
@@ -892,15 +863,9 @@ _draw_hershey_string (R___(_plotter) string)
 /* retrieve the two elements of a composite character from the table in
    g_fontdb.c */
 static bool
-#ifdef _HAVE_PROTOS
-_composite_char (unsigned char *composite, unsigned char *character, unsigned char *accent)
-#else
-_composite_char (composite, character, accent)
-     unsigned char *composite;
-     unsigned char *character, *accent;
-#endif
+composite_char (unsigned char *composite, unsigned char *character, unsigned char *accent)
 {
-  const struct plHersheyAccentedCharInfoStruct *compchar = _hershey_accented_char_info;
+  const struct plHersheyAccentedCharInfoStruct *compchar = _pl_g_hershey_accented_char_info;
   bool found = false;
   unsigned char given = *composite;
   
