@@ -1,3 +1,21 @@
+/* This file is part of the GNU plotutils package.  Copyright (C) 1995,
+   1996, 1997, 1998, 1999, 2000, 2005, Free Software Foundation, Inc.
+
+   The GNU plotutils package is free software.  You may redistribute it
+   and/or modify it under the terms of the GNU General Public License as
+   published by the Free Software foundation; either version 2, or (at your
+   option) any later version.
+
+   The GNU plotutils package is distributed in the hope that it will be
+   useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License along
+   with the GNU plotutils package; see the file COPYING.  If not, write to
+   the Free Software Foundation, Inc., 51 Franklin St., Fifth Floor,
+   Boston, MA 02110-1301, USA. */
+
 /* This file contains the box method, which is a standard part of libplot.
    It draws an object: a box, or upright rectangle with diagonal corners
    x0,y0 and x1,y1.  Boxes are one of the three types of primitive closed
@@ -14,13 +32,7 @@
 #include "extern.h"
 
 int
-#ifdef _HAVE_PROTOS
 _API_fbox (R___(Plotter *_plotter) double x0, double y0, double x1, double y1)
-#else
-_API_fbox (R___(_plotter) x0, y0, x1, y1)
-     S___(Plotter *_plotter;) 
-     double x0, y0, x1, y1;
-#endif
 {
   double xnew, ynew;
   plPoint p0, p1;
@@ -67,7 +79,7 @@ _API_fbox (R___(_plotter) x0, y0, x1, y1)
       if ((_plotter->drawstate->pen_type == 0 /* not edged */
 	   ||
 	   (_plotter->drawstate->dash_array_in_effect == false
-	    && _plotter->drawstate->line_type == L_SOLID)) /* solid edge */
+	    && _plotter->drawstate->line_type == PL_L_SOLID)) /* solid edge */
 	  &&
 	  ((_plotter->data->allowed_box_scaling == AS_ANY)
 	   ||
