@@ -1,3 +1,21 @@
+/* This file is part of the GNU plotutils package.  Copyright (C) 1995,
+   1996, 1997, 1998, 1999, 2000, 2005, Free Software Foundation, Inc.
+
+   The GNU plotutils package is free software.  You may redistribute it
+   and/or modify it under the terms of the GNU General Public License as
+   published by the Free Software foundation; either version 2, or (at your
+   option) any later version.
+
+   The GNU plotutils package is distributed in the hope that it will be
+   useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License along
+   with the GNU plotutils package; see the file COPYING.  If not, write to
+   the Free Software Foundation, Inc., 51 Franklin St., Fifth Floor,
+   Boston, MA 02110-1301, USA. */
+
 /* This file contains the linedash method, which is a GNU extension to
    libplot.  It sets a drawing attribute: the dash array used for
    subsequent drawing of paths. */
@@ -6,15 +24,7 @@
 #include "extern.h"
 
 int
-#ifdef _HAVE_PROTOS
 _API_flinedash (R___(Plotter *_plotter) int n, const double *dashes, double offset)
-#else
-_API_flinedash (R___(_plotter) n, dashes, offset)
-     S___(Plotter *_plotter;) 
-     int n;
-     const double *dashes;
-     double offset;
-#endif
 {
   double *dash_array;
   int i;
@@ -39,7 +49,7 @@ _API_flinedash (R___(_plotter) n, dashes, offset)
   if (_plotter->drawstate->dash_array_len > 0)
     free ((double *)_plotter->drawstate->dash_array);
   if (n > 0)
-    dash_array = (double *)_plot_xmalloc (n * sizeof(double));
+    dash_array = (double *)_pl_xmalloc (n * sizeof(double));
   else
     dash_array = NULL;
 
