@@ -1,3 +1,21 @@
+/* This file is part of the GNU plotutils package.  Copyright (C) 1995,
+   1996, 1997, 1998, 1999, 2000, 2005, Free Software Foundation, Inc.
+
+   The GNU plotutils package is free software.  You may redistribute it
+   and/or modify it under the terms of the GNU General Public License as
+   published by the Free Software foundation; either version 2, or (at your
+   option) any later version.
+
+   The GNU plotutils package is distributed in the hope that it will be
+   useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License along
+   with the GNU plotutils package; see the file COPYING.  If not, write to
+   the Free Software Foundation, Inc., 51 Franklin St., Fifth Floor,
+   Boston, MA 02110-1301, USA. */
+
 /* This file contains the linewidth method, which is a GNU extension to
    libplot.  It sets a drawing attribute: the line width used in subsequent
    drawing operations, in user units.
@@ -10,13 +28,7 @@
 #include "extern.h"
 
 int
-#ifdef _HAVE_PROTOS
 _API_flinewidth(R___(Plotter *_plotter) double new_line_width)
-#else
-_API_flinewidth(R___(_plotter) new_line_width)
-     S___(Plotter *_plotter;)
-     double new_line_width;
-#endif
 {
   double device_line_width, min_sing_val, max_sing_val;
   int quantized_device_line_width;
