@@ -1,3 +1,21 @@
+/* This file is part of the GNU plotutils package.  Copyright (C) 1995,
+   1996, 1997, 1998, 1999, 2000, 2005, Free Software Foundation, Inc.
+
+   The GNU plotutils package is free software.  You may redistribute it
+   and/or modify it under the terms of the GNU General Public License as
+   published by the Free Software foundation; either version 2, or (at your
+   option) any later version.
+
+   The GNU plotutils package is distributed in the hope that it will be
+   useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License along
+   with the GNU plotutils package; see the file COPYING.  If not, write to
+   the Free Software Foundation, Inc., 51 Franklin St., Fifth Floor,
+   Boston, MA 02110-1301, USA. */
+
 /* This file contains the libplot methods that take floating-point relative
    coordinates as arguments. */
 
@@ -5,13 +23,7 @@
 #include "extern.h"
 
 int
-#ifdef _HAVE_PROTOS
 _API_farcrel (R___(Plotter *_plotter) double dxc, double dyc, double dx0, double dy0, double dx1, double dy1)
-#else
-_API_farcrel (R___(_plotter) dxc, dyc, dx0, dy0, dx1, dy1)
-     S___(Plotter *_plotter;)
-     double dxc, dyc, dx0, dy0, dx1, dy1;
-#endif
 {
   return _API_farc (R___(_plotter) 
 		    _plotter->drawstate->pos.x + dxc, 
@@ -23,13 +35,7 @@ _API_farcrel (R___(_plotter) dxc, dyc, dx0, dy0, dx1, dy1)
 }
 
 int
-#ifdef _HAVE_PROTOS
 _API_fbezier2rel (R___(Plotter *_plotter) double dxc, double dyc, double dx0, double dy0, double dx1, double dy1)
-#else
-_API_fbezier2rel (R___(_plotter) dxc, dyc, dx0, dy0, dx1, dy1)
-     S___(Plotter *_plotter;)
-     double dxc, dyc, dx0, dy0, dx1, dy1;
-#endif
 {
   return _API_fbezier2 (R___(_plotter) 
 			_plotter->drawstate->pos.x + dxc, 
@@ -41,13 +47,7 @@ _API_fbezier2rel (R___(_plotter) dxc, dyc, dx0, dy0, dx1, dy1)
 }
 
 int
-#ifdef _HAVE_PROTOS
 _API_fbezier3rel (R___(Plotter *_plotter) double dx0, double dy0, double dx1, double dy1, double dx2, double dy2, double dx3, double dy3)
-#else
-_API_fbezier3rel (R___(_plotter) dx0, dy0, dx1, dy1, dx2, dy2, dx3, dy3)
-     S___(Plotter *_plotter;)
-     double dx0, dy0, dx1, dy1, dx2, dy2, dx3, dy3;
-#endif
 {
   return _API_fbezier3 (R___(_plotter) 
 			_plotter->drawstate->pos.x + dx0, 
@@ -61,13 +61,7 @@ _API_fbezier3rel (R___(_plotter) dx0, dy0, dx1, dy1, dx2, dy2, dx3, dy3)
 }
 
 int
-#ifdef _HAVE_PROTOS
 _API_fellarcrel (R___(Plotter *_plotter) double dxc, double dyc, double dx0, double dy0, double dx1, double dy1)
-#else
-_API_fellarcrel (R___(_plotter) dxc, dyc, dx0, dy0, dx1, dy1)
-     S___(Plotter *_plotter;)
-     double dxc, dyc, dx0, dy0, dx1, dy1;
-#endif
 {
   return _API_fellarc (R___(_plotter) 
 		       _plotter->drawstate->pos.x + dxc, 
@@ -79,13 +73,7 @@ _API_fellarcrel (R___(_plotter) dxc, dyc, dx0, dy0, dx1, dy1)
 }
 
 int
-#ifdef _HAVE_PROTOS
 _API_fboxrel (R___(Plotter *_plotter) double dx0, double dy0, double dx1, double dy1)
-#else
-_API_fboxrel (R___(_plotter) dx0, dy0, dx1, dy1)
-     S___(Plotter *_plotter;)
-     double dx0, dy0, dx1, dy1;
-#endif
 {
   return _API_fbox (R___(_plotter) 
 		    _plotter->drawstate->pos.x + dx0, 
@@ -95,13 +83,7 @@ _API_fboxrel (R___(_plotter) dx0, dy0, dx1, dy1)
 }
 
 int
-#ifdef _HAVE_PROTOS
 _API_fcirclerel (R___(Plotter *_plotter) double dx, double dy, double r)
-#else
-_API_fcirclerel (R___(_plotter) dx, dy, r)
-     S___(Plotter *_plotter;)
-     double dx, dy, r;
-#endif
 {
   return _API_fcircle (R___(_plotter) 
 		       _plotter->drawstate->pos.x + dx, 
@@ -109,13 +91,7 @@ _API_fcirclerel (R___(_plotter) dx, dy, r)
 }
 
 int
-#ifdef _HAVE_PROTOS
 _API_fellipserel (R___(Plotter *_plotter) double dx, double dy, double rx, double ry, double angle)
-#else
-_API_fellipserel (R___(_plotter) dx, dy, rx, ry, angle)
-     S___(Plotter *_plotter;)
-     double dx, dy, rx, ry, angle;
-#endif
 {
   return _API_fellipse (R___(_plotter) 
 			_plotter->drawstate->pos.x + dx, 
@@ -124,13 +100,7 @@ _API_fellipserel (R___(_plotter) dx, dy, rx, ry, angle)
 }
 
 int
-#ifdef _HAVE_PROTOS
 _API_fcontrel (R___(Plotter *_plotter) double dx, double dy)
-#else
-_API_fcontrel (R___(_plotter) dx, dy)
-     S___(Plotter *_plotter;)
-     double dx, dy;
-#endif
 {
   return _API_fcont (R___(_plotter) 
 		     _plotter->drawstate->pos.x + dx, 
@@ -138,13 +108,7 @@ _API_fcontrel (R___(_plotter) dx, dy)
 }
 
 int
-#ifdef _HAVE_PROTOS
 _API_flinerel (R___(Plotter *_plotter) double dx0, double dy0, double dx1, double dy1)
-#else
-_API_flinerel (R___(_plotter) dx0, dy0, dx1, dy1)
-     S___(Plotter *_plotter;)
-     double dx0, dy0, dx1, dy1;
-#endif
 {
   return _API_fline (R___(_plotter) 
 		     _plotter->drawstate->pos.x + dx0, 
@@ -154,15 +118,7 @@ _API_flinerel (R___(_plotter) dx0, dy0, dx1, dy1)
 }
 
 int
-#ifdef _HAVE_PROTOS
 _API_fmarkerrel (R___(Plotter *_plotter) double dx, double dy, int type, double size)
-#else
-_API_fmarkerrel (R___(_plotter) dx, dy, type, size)
-     S___(Plotter *_plotter;)
-     double dx, dy;
-     int type;
-     double size;
-#endif
 {
   return _API_fmarker (R___(_plotter) 
 		       _plotter->drawstate->pos.x + dx, 
@@ -171,13 +127,7 @@ _API_fmarkerrel (R___(_plotter) dx, dy, type, size)
 }
 
 int
-#ifdef _HAVE_PROTOS
 _API_fmoverel (R___(Plotter *_plotter) double x, double y)
-#else
-_API_fmoverel (R___(_plotter) x, y)
-     S___(Plotter *_plotter;)
-     double x, y;
-#endif
 {
   return _API_fmove (R___(_plotter) 
 		     _plotter->drawstate->pos.x + x, 
@@ -185,13 +135,7 @@ _API_fmoverel (R___(_plotter) x, y)
 }
 
 int
-#ifdef _HAVE_PROTOS
 _API_fpointrel (R___(Plotter *_plotter) double dx, double dy)
-#else
-_API_fpointrel (R___(_plotter) dx, dy)
-     S___(Plotter *_plotter;)
-     double dx, dy;
-#endif
 {
   return _API_fpoint (R___(_plotter) 
 		      _plotter->drawstate->pos.x + dx, 
