@@ -1,3 +1,21 @@
+/* This file is part of the GNU plotutils package.  Copyright (C) 1995,
+   1996, 1997, 1998, 1999, 2000, 2005, Free Software Foundation, Inc.
+
+   The GNU plotutils package is free software.  You may redistribute it
+   and/or modify it under the terms of the GNU General Public License as
+   published by the Free Software foundation; either version 2, or (at your
+   option) any later version.
+
+   The GNU plotutils package is distributed in the hope that it will be
+   useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License along
+   with the GNU plotutils package; see the file COPYING.  If not, write to
+   the Free Software Foundation, Inc., 51 Franklin St., Fifth Floor,
+   Boston, MA 02110-1301, USA. */
+
 /* This version is for both HPGLPlotters and PCLPlotters.  
 
    For HPGL Plotter objects, we output all plotted objects, which we have
@@ -9,12 +27,7 @@
 #include "extern.h"
 
 bool
-#ifdef _HAVE_PROTOS
-_h_end_page (S___(Plotter *_plotter))
-#else
-_h_end_page (S___(_plotter))
-     S___(Plotter *_plotter;)
-#endif
+_pl_h_end_page (S___(Plotter *_plotter))
 {
   /* output HP-GL epilogue to page buffer */
 
@@ -59,22 +72,12 @@ _h_end_page (S___(_plotter))
 }
 
 void
-#ifdef _HAVE_PROTOS
-_h_maybe_switch_from_hpgl (S___(Plotter *_plotter))
-#else
-_h_maybe_switch_from_hpgl (S___(_plotter))
-     S___(Plotter *_plotter;)
-#endif
+_pl_h_maybe_switch_from_hpgl (S___(Plotter *_plotter))
 {
 }
 
 void
-#ifdef _HAVE_PROTOS
-_q_maybe_switch_from_hpgl (S___(Plotter *_plotter))
-#else
-_q_maybe_switch_from_hpgl (S___(_plotter))
-     S___(Plotter *_plotter;)
-#endif
+_pl_q_maybe_switch_from_hpgl (S___(Plotter *_plotter))
 {
   /* switch back from HP-GL/2 to PCL 5 mode */
   strcpy (_plotter->data->page->point, "\033%0A");
