@@ -1,3 +1,21 @@
+/* This file is part of the GNU plotutils package.  Copyright (C) 1995,
+   1996, 1997, 1998, 1999, 2000, 2005, Free Software Foundation, Inc.
+
+   The GNU plotutils package is free software.  You may redistribute it
+   and/or modify it under the terms of the GNU General Public License as
+   published by the Free Software foundation; either version 2, or (at your
+   option) any later version.
+
+   The GNU plotutils package is distributed in the hope that it will be
+   useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License along
+   with the GNU plotutils package; see the file COPYING.  If not, write to
+   the Free Software Foundation, Inc., 51 Franklin St., Fifth Floor,
+   Boston, MA 02110-1301, USA. */
+
 /* The internal point-drawing function, which point() is a wrapper around.
    It draws a point at the current location.  There is no standard
    definition of `point', so any Plotter is free to implement this as it
@@ -8,12 +26,7 @@
 #include "xmi.h"
 
 void
-#ifdef _HAVE_PROTOS
-_i_paint_point (S___(Plotter *_plotter))
-#else
-_i_paint_point (S___(_plotter))
-     S___(Plotter *_plotter;)
-#endif
+_pl_i_paint_point (S___(Plotter *_plotter))
 {
   double xx, yy;
   int ixx, iyy;
@@ -33,7 +46,7 @@ _i_paint_point (S___(_plotter))
       iyy = IROUND(yy);
       
       /* compute background and foreground color for miGC */
-      _i_set_pen_color (S___(_plotter));
+      _pl_i_set_pen_color (S___(_plotter));
       bgPixel.type = MI_PIXEL_INDEX_TYPE;
       bgPixel.u.index = _plotter->drawstate->i_bg_color_index;
       fgPixel.type = MI_PIXEL_INDEX_TYPE;
@@ -44,7 +57,7 @@ _i_paint_point (S___(_plotter))
       /* construct an miGC (graphics context for the libxmi module); copy
 	 attributes from the Plotter's GC to it */
       pGC = miNewGC (2, pixels);
-      _set_common_mi_attributes (_plotter->drawstate, (voidptr_t)pGC);
+      _set_common_mi_attributes (_plotter->drawstate, (void *)pGC);
       
       point.x = ixx;
       point.y = iyy;
