@@ -1,3 +1,21 @@
+/* This file is part of the GNU plotutils package.  Copyright (C) 1995,
+   1996, 1997, 1998, 1999, 2000, 2005, Free Software Foundation, Inc.
+
+   The GNU plotutils package is free software.  You may redistribute it
+   and/or modify it under the terms of the GNU General Public License as
+   published by the Free Software foundation; either version 2, or (at your
+   option) any later version.
+
+   The GNU plotutils package is distributed in the hope that it will be
+   useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License along
+   with the GNU plotutils package; see the file COPYING.  If not, write to
+   the Free Software Foundation, Inc., 51 Franklin St., Fifth Floor,
+   Boston, MA 02110-1301, USA. */
+
 #include "sys-defines.h"
 #include "extern.h"
 
@@ -11,7 +29,7 @@
    and Cyan).  Also included are four points in the interior of the cube:
    Light Gray, Dark Gray, Violet, and Brown. */
 
-const plColor _idraw_stdcolors[IDRAW_NUM_STD_COLORS] =
+const plColor _pl_p_idraw_stdcolors[PS_NUM_IDRAW_STD_COLORS] =
 {
   {0x0000, 0x0000, 0x0000},	/* Black */
   {0xa500, 0x2a00, 0x2a00},	/* Brown */
@@ -27,7 +45,7 @@ const plColor _idraw_stdcolors[IDRAW_NUM_STD_COLORS] =
   {0x80e8, 0x80e8, 0x80e8}	/* DkGray */	  
 };
 
-const char * const _idraw_stdcolornames[IDRAW_NUM_STD_COLORS] = 
+const char * const _pl_p_idraw_stdcolornames[PS_NUM_IDRAW_STD_COLORS] = 
 {
   "Black", "Brown", "Red", "Orange", "Yellow", "Green",
   "Blue", "Indigo", "Violet", "White", "LtGray", "DkGray"
@@ -40,7 +58,7 @@ const char * const _idraw_stdcolornames[IDRAW_NUM_STD_COLORS] =
    background color.  (Idraw shadings are actually a special case of idraw
    patterns, which include bitmap fillings as well.) */
 
-const double _idraw_stdshadings[IDRAW_NUM_STD_SHADINGS] =
+const double _pl_p_idraw_stdshadings[PS_NUM_IDRAW_STD_SHADINGS] =
 {
   0.0, 0.25, 0.5, 0.75, 1.0
 };
