@@ -1,3 +1,21 @@
+/* This file is part of the GNU plotutils package.  Copyright (C) 1995,
+   1996, 1997, 1998, 1999, 2000, 2005, Free Software Foundation, Inc.
+
+   The GNU plotutils package is free software.  You may redistribute it
+   and/or modify it under the terms of the GNU General Public License as
+   published by the Free Software foundation; either version 2, or (at your
+   option) any later version.
+
+   The GNU plotutils package is distributed in the hope that it will be
+   useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License along
+   with the GNU plotutils package; see the file COPYING.  If not, write to
+   the Free Software Foundation, Inc., 51 Franklin St., Fifth Floor,
+   Boston, MA 02110-1301, USA. */
+
 /* This file defines the initialization for any SVGPlotter object,
    including both private data and public methods.  There is a one-to-one
    correspondence between public methods and user-callable functions in the
@@ -9,28 +27,28 @@
 #ifndef LIBPLOTTER
 /* In libplot, this is the initialization for the function-pointer part of
    a SVGPlotter struct. */
-const Plotter _s_default_plotter = 
+const Plotter _pl_s_default_plotter = 
 {
   /* initialization (after creation) and termination (before deletion) */
-  _s_initialize, _s_terminate,
+  _pl_s_initialize, _pl_s_terminate,
   /* page manipulation */
-  _s_begin_page, _s_erase_page, _s_end_page,
+  _pl_s_begin_page, _pl_s_erase_page, _pl_s_end_page,
   /* drawing state manipulation */
-  _g_push_state, _g_pop_state,
+  _pl_g_push_state, _pl_g_pop_state,
   /* internal path-painting methods (endpath() is a wrapper for the first) */
-  _s_paint_path, _s_paint_paths, _g_path_is_flushable, _g_maybe_prepaint_segments,
+  _pl_s_paint_path, _pl_s_paint_paths, _pl_g_path_is_flushable, _pl_g_maybe_prepaint_segments,
   /* internal methods for drawing of markers and points */
-  _g_paint_marker, _s_paint_point,
+  _pl_g_paint_marker, _pl_s_paint_point,
   /* internal methods that plot strings in Hershey, non-Hershey fonts */
-  _g_paint_text_string_with_escapes, _s_paint_text_string,
-  _g_get_text_width,
+  _pl_g_paint_text_string_with_escapes, _pl_s_paint_text_string,
+  _pl_g_get_text_width,
   /* private low-level `retrieve font' method */
-  _g_retrieve_font,
+  _pl_g_retrieve_font,
   /* `flush output' method, called only if Plotter handles its own output */
-  _g_flush_output,
+  _pl_g_flush_output,
   /* error handlers */
-  _g_warning,
-  _g_error,
+  _pl_g_warning,
+  _pl_g_error,
 };
 #endif /* not LIBPLOTTER */
 
@@ -41,16 +59,11 @@ const Plotter _s_default_plotter =
    created. */
 
 void
-#ifdef _HAVE_PROTOS
-_s_initialize (S___(Plotter *_plotter))
-#else
-_s_initialize (S___(_plotter))
-     S___(Plotter *_plotter;)
-#endif
+_pl_s_initialize (S___(Plotter *_plotter))
 {
 #ifndef LIBPLOTTER
   /* in libplot, manually invoke superclass initialization method */
-  _g_initialize (S___(_plotter));
+  _pl_g_initialize (S___(_plotter));
 #endif
 
   /* override generic initializations (which are appropriate to the base
@@ -82,10 +95,10 @@ _s_initialize (S___(_plotter))
      note that we don't set kern_stick_fonts, because it was set by the
      superclass initialization (and it's irrelevant for this Plotter type,
      anyway) */
-  _plotter->data->default_font_type = F_POSTSCRIPT;
+  _plotter->data->default_font_type = PL_F_POSTSCRIPT;
   _plotter->data->pcl_before_ps = false;
   _plotter->data->have_horizontal_justification = true;
-  _plotter->data->have_vertical_justification = true;
+  _plotter->data->have_vertical_justification = false;
   _plotter->data->issue_font_warning = true;
 
   /* path-related parameters (also internal); note that we
@@ -107,7 +120,7 @@ _s_initialize (S___(_plotter))
   _plotter->data->display_model_type = (int)DISP_MODEL_VIRTUAL;
   _plotter->data->display_coors_type = (int)DISP_DEVICE_COORS_REAL;
   _plotter->data->flipped_y = true;
-  _plotter->data->imin = 0;
+  _plotter->data->imin = 0;	/* not used */
   _plotter->data->imax = 0;  
   _plotter->data->jmin = 0;
   _plotter->data->jmax = 0;  
@@ -147,8 +160,9 @@ _s_initialize (S___(_plotter))
      element.  We do this additional flipping right now. */
 
   /* determine page type, and viewport size and location/offset (the
-     viewport size will be written out at the head of the SVG file, and the
-     location/offset will be ignored) */
+     viewport size, i.e., (xsize,ysize), will be written out at the head of
+     the SVG file, and the location/offset, i.e., (xorigin,yorigin) and
+     (xoffset,yoffset), will be ignored) */
   _set_page_type (_plotter->data);
 
   if (_plotter->data->viewport_xsize < 0.0)
@@ -174,12 +188,7 @@ _s_initialize (S___(_plotter))
    _plotter points to the Plotter that is about to be deleted. */
 
 void
-#ifdef _HAVE_PROTOS
-_s_terminate (S___(Plotter *_plotter))
-#else
-_s_terminate (S___(_plotter))
-     S___(Plotter *_plotter;)
-#endif
+_pl_s_terminate (S___(Plotter *_plotter))
 {
 }
 
@@ -187,64 +196,64 @@ _s_terminate (S___(_plotter))
 SVGPlotter::SVGPlotter (FILE *infile, FILE *outfile, FILE *errfile)
 	:Plotter (infile, outfile, errfile)
 {
-  _s_initialize ();
+  _pl_s_initialize ();
 }
 
 SVGPlotter::SVGPlotter (FILE *outfile)
 	:Plotter (outfile)
 {
-  _s_initialize ();
+  _pl_s_initialize ();
 }
 
 SVGPlotter::SVGPlotter (istream& in, ostream& out, ostream& err)
 	: Plotter (in, out, err)
 {
-  _s_initialize ();
+  _pl_s_initialize ();
 }
 
 SVGPlotter::SVGPlotter (ostream& out)
 	: Plotter (out)
 {
-  _s_initialize ();
+  _pl_s_initialize ();
 }
 
 SVGPlotter::SVGPlotter ()
 {
-  _s_initialize ();
+  _pl_s_initialize ();
 }
 
 SVGPlotter::SVGPlotter (FILE *infile, FILE *outfile, FILE *errfile, PlotterParams &parameters)
 	:Plotter (infile, outfile, errfile, parameters)
 {
-  _s_initialize ();
+  _pl_s_initialize ();
 }
 
 SVGPlotter::SVGPlotter (FILE *outfile, PlotterParams &parameters)
 	:Plotter (outfile, parameters)
 {
-  _s_initialize ();
+  _pl_s_initialize ();
 }
 
 SVGPlotter::SVGPlotter (istream& in, ostream& out, ostream& err, PlotterParams &parameters)
 	: Plotter (in, out, err, parameters)
 {
-  _s_initialize ();
+  _pl_s_initialize ();
 }
 
 SVGPlotter::SVGPlotter (ostream& out, PlotterParams &parameters)
 	: Plotter (out, parameters)
 {
-  _s_initialize ();
+  _pl_s_initialize ();
 }
 
 SVGPlotter::SVGPlotter (PlotterParams &parameters)
 	: Plotter (parameters)
 {
-  _s_initialize ();
+  _pl_s_initialize ();
 }
 
 SVGPlotter::~SVGPlotter ()
 {
-  _s_terminate ();
+  _pl_s_terminate ();
 }
 #endif
