@@ -1,3 +1,21 @@
+/* This file is part of the GNU plotutils package.  Copyright (C) 1995,
+   1996, 1997, 1998, 1999, 2000, 2005, Free Software Foundation, Inc.
+
+   The GNU plotutils package is free software.  You may redistribute it
+   and/or modify it under the terms of the GNU General Public License as
+   published by the Free Software foundation; either version 2, or (at your
+   option) any later version.
+
+   The GNU plotutils package is distributed in the hope that it will be
+   useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License along
+   with the GNU plotutils package; see the file COPYING.  If not, write to
+   the Free Software Foundation, Inc., 51 Franklin St., Fifth Floor,
+   Boston, MA 02110-1301, USA. */
+
 /* This file defines the initialization for any TekPlotter object,
    including both private data and public methods.  There is a one-to-one
    correspondence between public methods and user-callable functions in the
@@ -16,28 +34,28 @@
 #ifndef LIBPLOTTER
 /* In libplot, this is the initialization for the function-pointer part of
    a TekPlotter struct. */
-const Plotter _t_default_plotter = 
+const Plotter _pl_t_default_plotter = 
 {
   /* initialization (after creation) and termination (before deletion) */
-  _t_initialize, _t_terminate,
+  _pl_t_initialize, _pl_t_terminate,
   /* page manipulation */
-  _t_begin_page, _t_erase_page, _t_end_page,
+  _pl_t_begin_page, _pl_t_erase_page, _pl_t_end_page,
   /* drawing state manipulation */
-  _g_push_state, _g_pop_state,
+  _pl_g_push_state, _pl_g_pop_state,
   /* internal path-painting methods (endpath() is a wrapper for the first) */
-  _g_paint_path, _g_paint_paths, _t_path_is_flushable, _t_maybe_prepaint_segments,
+  _pl_g_paint_path, _pl_g_paint_paths, _pl_t_path_is_flushable, _pl_t_maybe_prepaint_segments,
   /* internal methods for drawing of markers and points */
-  _g_paint_marker, _t_paint_point,
+  _pl_g_paint_marker, _pl_t_paint_point,
   /* internal methods that plot strings in Hershey, non-Hershey fonts */
-  _g_paint_text_string_with_escapes, _g_paint_text_string,
-  _g_get_text_width,
+  _pl_g_paint_text_string_with_escapes, _pl_g_paint_text_string,
+  _pl_g_get_text_width,
   /* private low-level `retrieve font' method */
-  _g_retrieve_font,
+  _pl_g_retrieve_font,
   /* `flush output' method, called only if Plotter handles its own output */
-  _g_flush_output,
+  _pl_g_flush_output,
   /* error handlers */
-  _g_warning,
-  _g_error,
+  _pl_g_warning,
+  _pl_g_error,
 };
 #endif /* not LIBPLOTTER */
 
@@ -48,16 +66,11 @@ const Plotter _t_default_plotter =
    created. */
 
 void
-#ifdef _HAVE_PROTOS
-_t_initialize (S___(Plotter *_plotter))
-#else
-_t_initialize (S___(_plotter))
-     S___(Plotter *_plotter;)
-#endif
+_pl_t_initialize (S___(Plotter *_plotter))
 {
 #ifndef LIBPLOTTER
   /* in libplot, manually invoke superclass initialization method */
-  _g_initialize (S___(_plotter));
+  _pl_g_initialize (S___(_plotter));
 #endif
 
   /* override superclass initializations, as necessary */
@@ -88,14 +101,14 @@ _t_initialize (S___(_plotter))
      note that we don't set kern_stick_fonts, because it was set by the
      superclass initialization (and it's irrelevant for this Plotter type,
      anyway) */
-  _plotter->data->default_font_type = F_HERSHEY;
+  _plotter->data->default_font_type = PL_F_HERSHEY;
   _plotter->data->pcl_before_ps = false;
   _plotter->data->have_horizontal_justification = false;
   _plotter->data->have_vertical_justification = false;
   _plotter->data->issue_font_warning = true;
 
   /* path-related parameters (also internal) */
-  _plotter->data->max_unfilled_path_length = MAX_UNFILLED_PATH_LENGTH;
+  _plotter->data->max_unfilled_path_length = PL_MAX_UNFILLED_PATH_LENGTH;
   _plotter->data->have_mixed_paths = false;
   _plotter->data->allowed_arc_scaling = AS_NONE;
   _plotter->data->allowed_ellarc_scaling = AS_NONE;  
@@ -123,9 +136,9 @@ _t_initialize (S___(_plotter))
   _compute_ndc_to_device_map (_plotter->data);
 
   /* initialize data members specific to this derived class */
-  _plotter->tek_display_type = D_GENERIC;
-  _plotter->tek_mode = MODE_ALPHA;
-  _plotter->tek_line_type = L_SOLID;
+  _plotter->tek_display_type = TEK_DPY_GENERIC;
+  _plotter->tek_mode = TEK_MODE_ALPHA;
+  _plotter->tek_line_type = PL_L_SOLID;
   _plotter->tek_mode_is_unknown = true;
   _plotter->tek_line_type_is_unknown = true;
   _plotter->tek_kermit_fgcolor = -1; /* nonsensical value; means `unknown' */
@@ -148,17 +161,17 @@ _t_initialize (S___(_plotter))
 	if (strncmp (term_type, "xterm", 5) == 0
 	    || strncmp (term_type, "nxterm", 6) == 0
 	    || strncmp (term_type, "kterm", 5) == 0)
-	  _plotter->tek_display_type = D_XTERM;
+	  _plotter->tek_display_type = TEK_DPY_XTERM;
 	else if (strncmp (term_type, "ansi.sys", 8) == 0
 		 || strncmp (term_type, "nansi.sys", 9) == 0
 		 || strncmp (term_type, "ansisys", 7) == 0 /* undocumented */
 		 || strncmp (term_type, "kermit", 6) == 0)
-	  _plotter->tek_display_type = D_KERMIT;
+	  _plotter->tek_display_type = TEK_DPY_KERMIT;
 	else
-	  _plotter->tek_display_type = D_GENERIC;
+	  _plotter->tek_display_type = TEK_DPY_GENERIC;
       }
     else
-      _plotter->tek_display_type = D_GENERIC; /* default value */
+      _plotter->tek_display_type = TEK_DPY_GENERIC; /* default value */
   }      
 }
 
@@ -169,16 +182,11 @@ _t_initialize (S___(_plotter))
    deleted. */
 
 void
-#ifdef _HAVE_PROTOS
-_t_terminate (S___(Plotter *_plotter))
-#else
-_t_terminate (S___(_plotter))
-     S___(Plotter *_plotter;)
-#endif
+_pl_t_terminate (S___(Plotter *_plotter))
 {
 #ifndef LIBPLOTTER
   /* in libplot, manually invoke superclass termination method */
-  _g_terminate (S___(_plotter));
+  _pl_g_terminate (S___(_plotter));
 #endif
 }
 
@@ -186,64 +194,64 @@ _t_terminate (S___(_plotter))
 TekPlotter::TekPlotter (FILE *infile, FILE *outfile, FILE *errfile)
 	:Plotter (infile, outfile, errfile)
 {
-  _t_initialize ();
+  _pl_t_initialize ();
 }
 
 TekPlotter::TekPlotter (FILE *outfile)
 	:Plotter (outfile)
 {
-  _t_initialize ();
+  _pl_t_initialize ();
 }
 
 TekPlotter::TekPlotter (istream& in, ostream& out, ostream& err)
 	: Plotter (in, out, err)
 {
-  _t_initialize ();
+  _pl_t_initialize ();
 }
 
 TekPlotter::TekPlotter (ostream& out)
 	: Plotter (out)
 {
-  _t_initialize ();
+  _pl_t_initialize ();
 }
 
 TekPlotter::TekPlotter ()
 {
-  _t_initialize ();
+  _pl_t_initialize ();
 }
 
 TekPlotter::TekPlotter (FILE *infile, FILE *outfile, FILE *errfile, PlotterParams &parameters)
 	:Plotter (infile, outfile, errfile, parameters)
 {
-  _t_initialize ();
+  _pl_t_initialize ();
 }
 
 TekPlotter::TekPlotter (FILE *outfile, PlotterParams &parameters)
 	:Plotter (outfile, parameters)
 {
-  _t_initialize ();
+  _pl_t_initialize ();
 }
 
 TekPlotter::TekPlotter (istream& in, ostream& out, ostream& err, PlotterParams &parameters)
 	: Plotter (in, out, err, parameters)
 {
-  _t_initialize ();
+  _pl_t_initialize ();
 }
 
 TekPlotter::TekPlotter (ostream& out, PlotterParams &parameters)
 	: Plotter (out, parameters)
 {
-  _t_initialize ();
+  _pl_t_initialize ();
 }
 
 TekPlotter::TekPlotter (PlotterParams &parameters)
 	: Plotter (parameters)
 {
-  _t_initialize ();
+  _pl_t_initialize ();
 }
 
 TekPlotter::~TekPlotter ()
 {
-  _t_terminate ();
+  _pl_t_terminate ();
 }
 #endif
