@@ -1,3 +1,21 @@
+/* This file is part of the GNU plotutils package.  Copyright (C) 1995,
+   1996, 1997, 1998, 1999, 2000, 2005, Free Software Foundation, Inc.
+
+   The GNU plotutils package is free software.  You may redistribute it
+   and/or modify it under the terms of the GNU General Public License as
+   published by the Free Software foundation; either version 2, or (at your
+   option) any later version.
+
+   The GNU plotutils package is distributed in the hope that it will be
+   useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License along
+   with the GNU plotutils package; see the file COPYING.  If not, write to
+   the Free Software Foundation, Inc., 51 Franklin St., Fifth Floor,
+   Boston, MA 02110-1301, USA. */
+
 /* This file contains push_state() and pop_state() for XDrawablePlotters
    (and XPlotters).  They supplement the generic behavior of savestate()
    and restorestate(), which create and destroy drawing states on the
@@ -9,12 +27,7 @@
 #include "extern.h"
 
 void
-#ifdef _HAVE_PROTOS
-_x_push_state (S___(Plotter *_plotter))
-#else
-_x_push_state (S___(_plotter))
-     S___(Plotter *_plotter;)
-#endif
+_pl_x_push_state (S___(Plotter *_plotter))
 {
   Drawable drawable;
   XGCValues gcv;
@@ -38,7 +51,7 @@ _x_push_state (S___(_plotter))
       gcmask_fg = 
 	/* constant attributes (never altered) */
 	GCPlaneMask | GCFunction
-	/* drawing attributes set by _x_set_attributes() */
+	/* drawing attributes set by _pl_x_set_attributes() */
 	/* NOTE: we also use GCDashOffset and GCDashList, but Xlib does not
 	   support retrieving the dash list from a GC, so we'll copy the
 	   dashing style in another (painful) way */
@@ -49,7 +62,7 @@ _x_push_state (S___(_plotter))
       gcmask_fill = 
 	/* constant attributes (never altered) */
 	GCPlaneMask | GCFunction | GCArcMode 
-	/* filling attributes set by _x_set_attributes() */
+	/* filling attributes set by _pl_x_set_attributes() */
 	| GCFillRule
 	/* other GC elements set by the X Drawable driver */
 	| GCForeground;
@@ -82,7 +95,7 @@ _x_push_state (S___(_plotter))
 	  /* add non-opaque dash style elements */
 	  dash_list_len = 
 	    _plotter->drawstate->previous->x_gc_dash_list_len;
-	  dash_list = (char *)_plot_xmalloc (dash_list_len * sizeof(char));
+	  dash_list = (char *)_pl_xmalloc (dash_list_len * sizeof(char));
 	  for (i = 0; i < dash_list_len; i++)
 	    dash_list[i] =
 	      _plotter->drawstate->previous->x_gc_dash_list[i];
@@ -115,18 +128,13 @@ _x_push_state (S___(_plotter))
 }
 
 void
-#ifdef _HAVE_PROTOS
-_x_pop_state (S___(Plotter *_plotter))
-#else
-_x_pop_state (S___(_plotter))
-     S___(Plotter *_plotter;)
-#endif
+_pl_x_pop_state (S___(Plotter *_plotter))
 {
   /* N.B. we do _not_ free _plotter->drawstate->x_font_struct anywhere,
      when restorestate() is invoked on an X Drawable or X Plotter */
 
   /* Free graphics contexts, if we have them -- and to have them, must have
-     at least one drawable (see _x_push_state()). */
+     at least one drawable (see _pl_x_push_state()). */
   if (_plotter->x_drawable1 || _plotter->x_drawable2)
     {
       /* free the dash list in the X11-specific part of the drawing state */
