@@ -1,19 +1,22 @@
+/* This file is part of the GNU plotutils package. */
+
+/*
+ * Copyright (C) 1982-1994, Nicholas B. Tufillaro.  All rights reserved.
+ *
+ * GNU enhancements Copyright (C) 1996, 1997, 2005, Free Software
+ * Foundation, Inc.
+ */
+
 #include "sys-defines.h"
 #include "ode.h"
 #include "extern.h"
 
 /*
  * Euler's method: quick and dirty.
- * Copyright Nicholas B. Tufillaro, 1982-1994. All rights reserved.
- * GNU enhancements copyright (C) 1996-1997 Free Software Foundation, Inc.
  */
 
 void
-#ifdef _HAVE_PROTOS
 eu (void)
-#else
-eu ()
-#endif
 {
   double t;
   
@@ -36,11 +39,7 @@ eu ()
  * if tstart == tstop, i.e., step nowhere, then just print current values
  */
 void
-#ifdef _HAVE_PROTOS
 trivial (void)
-#else
-trivial ()
-#endif
 {
   symtab->sy_value = symtab->sy_val[0] = tstart;
   field();
