@@ -1,3 +1,17 @@
+/* This file is part of the GNU plotutils package. */
+
+/*
+ * Copyright (C) 1982-1994, Nicholas B. Tufillaro.  All rights reserved.
+ *
+ * GNU enhancements Copyright (C) 1996, 1997, 2005, Free Software
+ * Foundation, Inc.
+ */
+
+/*
+ * Fifth-Order Runge-Kutta-Fehlberg with adaptive step size
+ *
+ */
+
 #include "sys-defines.h"
 #include "ode.h"
 #include "extern.h"
@@ -5,18 +19,8 @@
 
 #define T_LT_TSTOP (tstep>0 ? t<tstop : t>tstop)
 
-/*
- * Fifth-Order Runge-Kutta-Fehlberg with adaptive step size
- * Copyright Nicholas B. Tufillaro, 1982-1994. All rights reserved.
- * GNU enhancements copyright (C) 1996-1997 Free Software Foundation, Inc.
- */
-
 void
-#ifdef _HAVE_PROTOS
 rka (void)
-#else
-rka ()
-#endif
 {
   bool gdval = true; 		/* good value to print ? */
   int overtime = 1;
